// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using System.Runtime.Serialization;

namespace TopCoder.Util.ConfigurationManager
{
    /// <summary>
    /// Exception thrown when an error occurs while loading a configuration
    /// file (signaling the file is invalid). If the error is caused by
    /// another exception (XML parsing exceptions for example) then the
    /// other exception is wrapped as inner exception. I/O exceptions are
    /// not included here. They should be propagated.
    /// </summary>
    [Serializable]
    public class InvalidConfigFileException: Exception
    {
        /// <summary>
        /// Constructor.
        /// </summary>
        public InvalidConfigFileException(): base()
        {
        }

        /// <summary>
        /// Constructor.
        /// </summary>
        /// 
        /// <param name="message">the error message</param>
        public InvalidConfigFileException(string message): base(message)
        {
        }

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="info">the serialization info</param>
        /// <param name="context">the streaming context</param>
        public InvalidConfigFileException(SerializationInfo info, StreamingContext context): base(info, context)
        {
        }
        
        /// <summary>
        /// Constructor.
        /// </summary>
        /// 
        /// <param name="message">the error message</param>
        /// <param name="inner">the inner exception</param>
        public InvalidConfigFileException(string message, Exception inner): 
                base(message, inner)
        {
        }
    }
}
