// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using System.Runtime.Serialization;

namespace TopCoder.Util.ConfigurationManager
{
    /// <summary>
    /// Exception thrown when the configuration file cannot be saved or unloaded because
    /// some of its namespaces or properties were merged, so it is unsafe to save or unload it
    /// as the saved config file will be mixed with data from other config files or
    /// the removal might corrupt other config files loaded in memory.
    /// </summary>
    [Serializable]
    public class MergeException: Exception
    {
        /// <summary>
        /// Constructor.
        /// </summary>
        public MergeException(): base()
        {
        }

        /// <summary>
        /// Constructor.
        /// </summary>
        /// 
        /// <param name="message">the error message</param>
        public MergeException(string message): base(message)
        {
        }
        
        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="info">the serialization info</param>
        /// <param name="context">the streaming context</param>
        public MergeException(SerializationInfo info, StreamingContext context): base(info, context)
        {
        }

        /// <summary>
        /// Constructor.
        /// </summary>
        /// 
        /// <param name="message">the error message</param>
        /// <param name="inner">the inner exception</param>
        public MergeException(string message, Exception inner): 
                base(message, inner)
        {
        }
    }
}
