// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

// Copyright (c)2005, TopCoder, Inc. All rights reserved
// @author TCSDEVELOPER
// @version 2.0

using System;

namespace TopCoder.Util.ConfigurationManager
{
    /// <summary>
    /// This class corresponds to a property.
    /// A property has a name and more string values.
    /// The class exposes properties to access the name and the values.
    /// Only the values are modifiable.
    /// </summary>
    public class Property : MarshalByRefObject
    {
        /// <summary>
        /// The name of the property.
        /// </summary>
        private string name = null;
        
        /// <summary>
        /// The values of the property (only one element for most
        /// properties).
        /// </summary>
        private string[] values = null;

        /// <summary>
        /// Is this property merged with another because of a name conflict?
        /// </summary>
        internal bool isMerged = false;

        /// <summary>
        /// Internal constructor. The user doesn't need to create new 
        /// instances.
        /// </summary>
        /// 
        /// <param name="name">The name of the property</param>
        /// <param name="values">The values of the property (one or more)</param>
        internal Property(string name, string[] values)
        {
            this.name = name;
            this.values = values;
        }
        
        /// <summary>
        /// The Name property.
        /// </summary>
        /// <value>
        /// The name of the property.
        /// </value>
        public string Name
        {
            get
            {
                return name;
            }
        }
        
        /// <summary>
        /// The Value property.
        /// The getter will return the first element in the array
        /// if there are more or an empty string if there isn't any.
        /// The setter will create an array with one element from the given
        /// value.
        /// </summary>
        /// <value>
        /// The value of the property.
        /// </value>
        /// 
        /// <exception cref="NullReferenceException">
        /// if value is null
        /// </exception>
        public string Value
        {
            get
            {
                if (values == null)
                {
                    throw new NullReferenceException();
                }
                if (values.Length > 0)
                {
                    return values[0];
                }
                else
                {
                    return "";
                }
            }
            set
            {
                lock (this)
                {
                    if (value == null)
                    {
                        throw new NullReferenceException();
                    }
                    values = new string[1]; 
                    values[0] = value; 
                }
            }
        }
        
        /// <summary>
        /// The Values property.
        /// </summary>
        /// <value>
        /// The values of the property.
        /// </value>
        /// 
        /// <exception cref="NullReferenceException">
        /// if values is null
        /// </exception>
        public string[] Values
        {
            get
            {
                if (values == null)
                {
                    throw new NullReferenceException();
                }
                return values;
            }
            set
            {
                lock (this)
                {
                    if (value == null)
                    {
                        throw new NullReferenceException();
                    }
                    values = value;
                }
            }
        }
    }
}
