/*
 * Copyright (c)2005, TopCoder, Inc. All rights reserved
 * @author sinaddcos
 * @version 2.0
 */
using System;
using System.Collections;
using System.Reflection;
using NUnit.Framework;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.Util.ConfigurationManager.Test.Accuray
{
    /// <summary>
    /// Test the newly added functionality in the ConfigManger class of version 2.0 
    /// </summary>
    [TestFixture]
    public class AccuracyTestConfigManger
    {
        /// <summary>
        /// The xml config file.
        /// </summary>
        private const string xmlConfigFile = "../../test_files/accuracy/accuracy.xml";

        /// <summary>
        /// The config manager instance.
        /// </summary>
        ConfigManager cm = null;

        /// <summary>
        /// Set Up environment.
        /// </summary>
        [SetUp]
        public void SetUp() 
        {
            cm = ConfigManager.GetInstance();
            if (cm.GetConfigFile(xmlConfigFile) == null)
            {
                cm.LoadFile(xmlConfigFile);
            }
        }

        /// <summary>
        /// Remove the loaded files.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
            cm.RemoveFile(xmlConfigFile);
        }
        
        /// <summary>
        /// Test the CreateInstance methods.
        /// </summary>
        [Test]
        public void TestCreateIntance()
        {
            Assert.AreEqual(typeof(int), 
                cm.CreateInstance("AccuracyNs1", "instance_type", typeof(object)).GetType());
            Assert.AreEqual("aaa", 
                cm.CreateInstance("AccuracyNs2", "instance_type", new object[] {'a', 3}, typeof(object)));
            Assert.AreEqual(new Person("person").ToString(), cm.CreateInstance("AccuracyNs3", "instance_type", 
                    "instance_assembly", new object[] {"person"}, typeof(object)).ToString());

        }

        /// <summary>
        /// Test the GetValue methods.
        /// </summary>
        [Test]
        public void TestGetValue()
        {
            Assert.AreEqual(12345, cm.GetValue("AccuracyNs3", "int_value", typeof(int)));
            Assert.AreEqual(0.1, cm.GetValue("AccuracyNs3", "double_value", typeof(double)));
            Assert.AreEqual("a", cm.GetValue("AccuracyNs3", "string_value", typeof(string)));
        }

        /// <summary>
        /// Test the GetValues methods.
        /// </summary>
        [Test]
        public void TestGetValues()
        {
            int[] intValues = (int[]) new ArrayList(
                        cm.GetValues("AccuracyNs3", "int_values", typeof(int))).ToArray(typeof(int));
            Array.Sort(intValues);
            Assert.AreEqual(-1, intValues[0]);
            Assert.AreEqual(2, intValues[1]);
            Assert.AreEqual(3, intValues[2]);

            double[] doubleValues = (double[]) new ArrayList(
                        cm.GetValues("AccuracyNs3", "double_values", typeof(double))).ToArray(typeof(double));
            Array.Sort(doubleValues);
            Assert.AreEqual(-0.1, doubleValues[0]);
            Assert.AreEqual(0.1, doubleValues[1]);
            Assert.AreEqual(1e30, doubleValues[2]);

            Array ar = cm.GetValues("AccuracyNs3", "string_values", typeof(string));
            string[] stringValues = (string[]) new ArrayList(ar).ToArray(typeof(string));

            Array.Sort(stringValues);
            Assert.AreEqual(3, stringValues.Length);
            Assert.AreEqual("a", stringValues[0]);
            Assert.AreEqual("b", stringValues[1]);
            Assert.AreEqual("c", stringValues[2]);
        }

        /// <summary>
        /// Test GetIntValue and GetIntValues method.
        /// </summary>
        [Test]
        public void TestGetInt()
        {
            Assert.AreEqual(12345, cm.GetIntValue("AccuracyNs3", "int_value"));
            int[] values = cm.GetIntValues("AccuracyNs3", "int_values");
            Assert.AreEqual(3, values.Length);
            Array.Sort(values);
            Assert.AreEqual(-1, values[0]);
            Assert.AreEqual(2, values[1]);
            Assert.AreEqual(3, values[2]);
        }

        /// <summary>
        /// Test GetDoubleValue and GetDoubleValues method.
        /// </summary>
        [Test]
        public void TestGetDouble()
        {
            Assert.AreEqual(0.1, cm.GetDoubleValue("AccuracyNs3", "double_value"));
            double[] values = cm.GetDoubleValues("AccuracyNs3", "double_values");
            Assert.AreEqual(3, values.Length);
            Array.Sort(values);
            Assert.AreEqual(-0.1, values[0]);
            Assert.AreEqual(0.1, values[1]);
            Assert.AreEqual(1e30, values[2]);
        }
    }

    /// <summary>
    /// A Person class used for testing, same with the class in the assembly Person.dll.
    /// </summary>
    public class Person
    {
        /// <summary>
        /// Represent the name of the person.
        /// </summary>
        private string name = "";

        /// <summary>
        /// Ctor.
        /// </summary>
        /// <param name="name">The name of the person</param>
        public Person(string name)
        {
            this.name = name;
        }

        /// <summary>
        /// Convert the object to string.
        /// </summary>
        /// <returns></returns>
        public override string ToString()
        {
            return this.name;
        }
    }
}
