/*
 * Copyright (c)2005, TopCoder, Inc. All rights reserved
 * @author sinaddcos
 * @version 2.0
 */
using System;
using System.Collections;
using NUnit.Framework;
using TopCoder.Util.ConfigurationManager;

namespace TopCoder.Util.ConfigurationManager.Test.Accuray
{
    /// <summary>
    /// Test the accuracy of the PluggableHandler class.
    /// A DummyDataHandler is used in the test.
    /// </summary>
    [TestFixture]
    public class AccuracyTestPluggableHandler
    {
        /// <summary>
        /// The mxml config file.
        /// </summary>
        private const string mxmlConfigFile = "../../test_files/accuracy/accuracy.mxml";

        /// <summary>
        /// The xml config file.
        /// </summary>
        private const string xmlConfigFile = "../../test_files/accuracy/accuracy.xml";

        /// <summary>
        /// The config manager instance.
        /// </summary>
        ConfigManager cm = null;

        /// <summary>
        /// Set Up environment.
        /// </summary>
        [SetUp]
        public void SetUp() 
        {
            cm = ConfigManager.GetInstance();
            if (cm.GetConfigFile(xmlConfigFile) == null)
            {
                cm.LoadFile(xmlConfigFile);
            }
            if (cm.GetConfigFile(mxmlConfigFile) == null)
            {
                cm.LoadFile(mxmlConfigFile);
            }
        }

        /// <summary>
        /// Remove the loaded files.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
            cm.RemoveFile(xmlConfigFile);
            cm.RemoveFile(mxmlConfigFile);
        }

        /// <summary>
        /// Test PluggableDataHandler.
        /// This test focus on the Load method.
        /// </summary>
        [Test]
        public void TestPluggableDataHandler1()
        {
            ConfigFile mxml = cm.GetConfigFile(mxmlConfigFile);
            // Get the namespaces in the DummyDataHandler.
            Namespace[] ns = mxml.Namespaces;
            Assert.AreEqual(0, ns.Length, "Initaily no namespaces exist in DummyDataHandler");
        }

        /// <summary>
        /// Test PluggableDataHandler.
        /// This test focus on both the Load and the Save method implementation.
        /// </summary>
        [Test]
        public void TestPluggableDataHandler2()
        {
            IList a = new string[] {"a", "b"};

            // Get the namespaces in mxml config file the data source is the DummyDataHandler.
            Namespace[] ns = cm.GetConfigFile(mxmlConfigFile).Namespaces;
            Assert.AreEqual(0, ns.Length, "Initaily no namespaces exist in DummyDataHandler");

            // Get the namespaces from the xml config file, there are 3 namespaces.
            ns = cm.GetConfigFile(xmlConfigFile).Namespaces;
            Assert.AreEqual(3, ns.Length, "There are 3 namespaces in the xml config file.");

            // Save the namespaces from xmlConfigFile to mxmlConfigFile
            cm.SaveFileTo(xmlConfigFile, mxmlConfigFile);

            // And remove the xmlConfigFile to avoid namespace clashes.
            cm.RemoveFile(xmlConfigFile);

            // Reload the mxmlConfigfile.
            cm.ReloadFile(mxmlConfigFile);

            // Get the namespaces in mxml config file the data source is the DummyDataHandler again,
            // This time there should be 3 namespaces.
            ns = cm.GetConfigFile(mxmlConfigFile).Namespaces;
            Assert.AreEqual(3, ns.Length, "There are 3 namespaces in the xml config file.");
        }
    }
}
