/*
	Copyright c 2003, TopCoder, Inc. All rights reserved.
	Author pzhao
*/

using System;
using NUnit.Framework;

using TopCoder.Util.ConfigurationManager;

namespace TopCoder.Util.ConfigurationManager.AccuracyTests
{
    /// <summary>
    /// Accuracy test cases related to the namespace class.
    /// </summary>
    [TestFixture]
    public class NamespaceAccuracyTest
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;

        /// <summary>
        /// The configuration file instance.
        /// </summary>
        private ConfigFile cf = null;

        /// <summary>
        /// The namespace instance.
        /// </summary>
        private Namespace[] ns = new Namespace[2];
        
        /// <summary>
        /// Initialization
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
            cf = cm.LoadFile(@"..\..\test_files\AccuracyTest.ini");

            ns[0] = cm.GetNamespace("AccuracyNamespace1");
            ns[1] = cm.GetNamespace("AccuracyNamespace2");
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
            cm.RemoveFile(@"..\..\test_files\AccuracyTest.ini");
        }

        /// <summary>
        /// Test get name.
        /// </summary>
        [Test]
        public void TestGetName()
        {
            Assertion.AssertEquals(ns[0].Name, "AccuracyNamespace1");
            Assertion.AssertEquals(ns[1].Name, "AccuracyNamespace2");
        }

        /// <summary>
        /// Test properties.
        /// </summary>
        [Test]
        public void TestProperties()
        {
            Assertion.AssertEquals(ns[0].Properties.Length, 3);
            Assertion.AssertEquals(ns[0].Properties[0].Name, "AccuracyProp1");
            Assertion.AssertEquals(ns[0].Properties[1].Name, "AccuracyProp2");
            Assertion.AssertEquals(ns[0].Properties[2].Name, "AccuracyProp3");
            
            Assertion.AssertEquals(ns[1].Properties.Length, 3);
            Assertion.AssertEquals(ns[1].Properties[0].Name, "AccuracyProp1");
            Assertion.AssertEquals(ns[1].Properties[1].Name, "AccuracyProp2");
            Assertion.AssertEquals(ns[1].Properties[2].Name, "AccuracyProp3");
        }

        /// <summary>
        /// Test get property.
        /// </summary>
        [Test]
        public void TestGetProperty()
        {
            Assertion.AssertEquals(ns[0].GetProperty("AccuracyProp1").Values.Length, 1);
            Assertion.AssertEquals(ns[0].GetProperty("AccuracyProp1").Values[0], "AccuracyValue1");
            Assertion.AssertEquals(ns[0].GetProperty("AccuracyProp2").Values.Length, 2);
            Assertion.AssertEquals(ns[0].GetProperty("AccuracyProp2").Values[0], "AccuracyValue2");
            Assertion.AssertEquals(ns[0].GetProperty("AccuracyProp2").Values[1], "AccuracyValue1");
            Assertion.AssertEquals(ns[0].GetProperty("AccuracyProp3").Values.Length, 3);
            Assertion.AssertEquals(ns[0].GetProperty("AccuracyProp3").Values[0], "AccuracyValue3");
            Assertion.AssertEquals(ns[0].GetProperty("AccuracyProp3").Values[1], "AccuracyValue2");
            Assertion.AssertEquals(ns[0].GetProperty("AccuracyProp3").Values[2], "AccuracyValue1");
            Assertion.AssertEquals(ns[1].GetProperty("AccuracyProp1").Values.Length, 3);
            Assertion.AssertEquals(ns[1].GetProperty("AccuracyProp1").Values[0], "AccuracyValue3");
            Assertion.AssertEquals(ns[1].GetProperty("AccuracyProp1").Values[1], "AccuracyValue2");
            Assertion.AssertEquals(ns[1].GetProperty("AccuracyProp1").Values[2], "AccuracyValue1");
            Assertion.AssertEquals(ns[1].GetProperty("AccuracyProp2").Values.Length, 2);
            Assertion.AssertEquals(ns[1].GetProperty("AccuracyProp2").Values[0], "AccuracyValue2");
            Assertion.AssertEquals(ns[1].GetProperty("AccuracyProp2").Values[1], "AccuracyValue1");
            Assertion.AssertEquals(ns[1].GetProperty("AccuracyProp3").Values.Length, 1);
            Assertion.AssertEquals(ns[1].GetProperty("AccuracyProp3").Values[0], "AccuracyValue1");
        }

        /// <summary>
        /// Test indexer.
        /// </summary>
        [Test]
        public void TestIndexer()
        {
            Assertion.AssertEquals(ns[0]["AccuracyProp1"], "AccuracyValue1");
            Assertion.AssertEquals(ns[0]["AccuracyProp2"], "AccuracyValue2");
            Assertion.AssertEquals(ns[0]["AccuracyProp3"], "AccuracyValue3");
            Assertion.AssertEquals(ns[1]["AccuracyProp1"], "AccuracyValue3");
            Assertion.AssertEquals(ns[1]["AccuracyProp2"], "AccuracyValue2");
            Assertion.AssertEquals(ns[1]["AccuracyProp3"], "AccuracyValue1");
        }
    }
}