/*
	Copyright c 2003, TopCoder, Inc. All rights reserved.
	Author pzhao
*/

using System;
using NUnit.Framework;

using TopCoder.Util.ConfigurationManager;

namespace TopCoder.Util.ConfigurationManager.AccuracyTests
{
    /// <summary>
    /// Accuracy test cases related to the property class.
    /// </summary>
    [TestFixture]
    public class PropertyAccuracyTest
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;

        /// <summary>
        /// The configuration file instance.
        /// </summary>
        private ConfigFile cf = null;

        /// <summary>
        /// The property instance.
        /// </summary>
        private Property[] ps = new Property[6];
        
        /// <summary>
        /// Initialization
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
            cf = cm.LoadFile(@"..\..\test_files\AccuracyTest.ini");

            ps[0] = cm.GetProperty("AccuracyNamespace1", "AccuracyProp1");
            ps[1] = cm.GetProperty("AccuracyNamespace1", "AccuracyProp2");
            ps[2] = cm.GetProperty("AccuracyNamespace1", "AccuracyProp3");
            ps[3] = cm.GetProperty("AccuracyNamespace2", "AccuracyProp1");
            ps[4] = cm.GetProperty("AccuracyNamespace2", "AccuracyProp2");
            ps[5] = cm.GetProperty("AccuracyNamespace2", "AccuracyProp3");
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
            cm.RemoveFile(@"..\..\test_files\AccuracyTest.ini");
        }

        /// <summary>
        /// Test get name.
        /// </summary>
        [Test]
        public void TestGetName()
        {
            Assertion.AssertEquals(ps[0].Name, "AccuracyProp1");
            Assertion.AssertEquals(ps[1].Name, "AccuracyProp2");
            Assertion.AssertEquals(ps[2].Name, "AccuracyProp3");
            Assertion.AssertEquals(ps[3].Name, "AccuracyProp1");
            Assertion.AssertEquals(ps[4].Name, "AccuracyProp2");
            Assertion.AssertEquals(ps[5].Name, "AccuracyProp3");
        }

        /// <summary>
        /// Test get value.
        /// </summary>
        [Test]
        public void TestGetValue()
        {
            Assertion.AssertEquals(ps[0].Value, "AccuracyValue1");
            Assertion.AssertEquals(ps[1].Value, "AccuracyValue2");
            Assertion.AssertEquals(ps[2].Value, "AccuracyValue3");
            Assertion.AssertEquals(ps[3].Value, "AccuracyValue3");
            Assertion.AssertEquals(ps[4].Value, "AccuracyValue2");
            Assertion.AssertEquals(ps[5].Value, "AccuracyValue1");
        }

        /// <summary>
        /// Test get values.
        /// </summary>
        [Test]
        public void TestGetValues()
        {
            Assertion.AssertEquals(ps[0].Values.Length, 1);
            Assertion.AssertEquals(ps[0].Values[0], "AccuracyValue1");
            Assertion.AssertEquals(ps[1].Values.Length, 2);
            Assertion.AssertEquals(ps[1].Values[0], "AccuracyValue2");
            Assertion.AssertEquals(ps[1].Values[1], "AccuracyValue1");
            Assertion.AssertEquals(ps[2].Values.Length, 3);
            Assertion.AssertEquals(ps[2].Values[0], "AccuracyValue3");
            Assertion.AssertEquals(ps[2].Values[1], "AccuracyValue2");
            Assertion.AssertEquals(ps[2].Values[2], "AccuracyValue1");
            Assertion.AssertEquals(ps[3].Values.Length, 3);
            Assertion.AssertEquals(ps[3].Values[0], "AccuracyValue3");
            Assertion.AssertEquals(ps[3].Values[1], "AccuracyValue2");
            Assertion.AssertEquals(ps[3].Values[2], "AccuracyValue1");
            Assertion.AssertEquals(ps[4].Values.Length, 2);
            Assertion.AssertEquals(ps[4].Values[0], "AccuracyValue2");
            Assertion.AssertEquals(ps[4].Values[1], "AccuracyValue1");
            Assertion.AssertEquals(ps[5].Values.Length, 1);
            Assertion.AssertEquals(ps[5].Values[0], "AccuracyValue1");
        }

        /// <summary>
        /// Test set value.
        /// </summary>
        [Test]
        public void TestSetValue()
        {
            ps[0].Value = "NewValue1";
            Assertion.AssertEquals(ps[0].Value, "NewValue1");

            ps[1].Value = "NewValue2";
            Assertion.AssertEquals(ps[1].Value, "NewValue2");
        }

        /// <summary>
        /// Test set values.
        /// </summary>
        [Test]
        public void TestSetValues()
        {
            ps[0].Values[0] = "NewValue1";
            Assertion.AssertEquals(ps[0].Values[0], "NewValue1");

            ps[1].Values[1] = "NewValue2";
            Assertion.AssertEquals(ps[1].Values[1], "NewValue2");
        }
    }
}