// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.FunctionalTests
{
    /// <summary>
    /// Functional tests for the Get Properties Values use case.
    /// </summary>
    [TestFixture]
    public class GetPropertiesValuesTestCase
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
        }

        /// <summary>
        /// Test get value.
        /// </summary>
        [Test]
        public void TestGetValue()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            String value = cm.GetValue("section1", "prop1");
            Assertion.AssertNotNull(value);
            Assertion.Assert(value.Equals("value1"));
            
            value = cm.GetValue("section1", "prop2");
            Assertion.AssertNotNull(value);
            Assertion.Assert(value.Equals("value1"));
            
            value = cm.GetValue("section1", "prop3");
            Assertion.AssertNotNull(value);
            Assertion.Assert(value.Equals("value1"));
            
            value = cm.GetValue("section2", "prop1");
            Assertion.AssertNotNull(value);
            Assertion.Assert(value.Equals("value1"));
            
            value = cm.GetValue("section2", "prop2");
            Assertion.AssertNotNull(value);
            Assertion.Assert(value.Equals("value1"));
            
            value = cm.GetValue("section2", "prop3");
            Assertion.AssertNotNull(value);
            Assertion.Assert(value.Equals("value1"));
            
            cm.RemoveFile(@"..\..\test_files\test.ini");
        }
        
        /// <summary>
        /// Test get values.
        /// </summary>
        [Test]
        public void TestGetValues()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            String[] values = cm.GetValues("section1", "prop1");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 1);
            Assertion.Assert(values[0].Equals("value1"));
            
            values = cm.GetValues("section1", "prop2");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 2);
            Assertion.Assert(values[0].Equals("value1") && 
                             values[1].Equals("value2"));
            
            values = cm.GetValues("section1", "prop3");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 3);
            Assertion.Assert(values[0].Equals("value1") && 
                             values[1].Equals("value2") && 
                             values[2].Equals("value3"));
            
            values = cm.GetValues("section2", "prop1");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 1);
            Assertion.Assert(values[0].Equals("value1"));
            
            values = cm.GetValues("section2", "prop2");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 2);
            Assertion.Assert(values[0].Equals("value1") && 
                             values[1].Equals("value2"));
            
            values = cm.GetValues("section2", "prop3");
            Assertion.AssertNotNull(values);
            Assertion.Assert(values.Length == 3);
            Assertion.Assert(values[0].Equals("value1") && 
                             values[1].Equals("value2") && 
                             values[2].Equals("value3"));
            
            cm.RemoveFile(@"..\..\test_files\test.ini");
        }
    }
}
