// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.FunctionalTests
{
    /// <summary>
    /// Functional tests for the Reload Save Configuration File use case.
    /// </summary>
    [TestFixture]
    public class SaveConfigurationFileTestCase
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
            File.Delete(@"..\..\test_files\testtemp.ini");
            File.Delete(@"..\..\test_files\testtemp.xml");
        }

        /// <summary>
        /// Test save to ini.
        /// </summary>
        [Test]
        public void TestSaveToIni()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            String values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("value1"));
            
            Assertion.Assert(cm.SetValue("section1", "prop1", "newvalue"));
            
            values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("newvalue"));

            String[] vals = cm.GetValues("section1", "prop1");
            Assertion.Assert(vals != null && vals.Length == 1);
            Assertion.Assert(vals[0].Equals("newvalue"));
            
            // save, unload and make sure unload is ok
            cm.SaveFileTo(@"..\..\test_files\test.ini", @"..\..\test_files\testtemp.ini");
            cm.RemoveFile(@"..\..\test_files\test.ini");
            Assertion.AssertNull(cm.GetValue("section1", "prop1"));
            
            // test if changes were saved properly
            cf = cm.LoadFile(@"..\..\test_files\testtemp.ini");
            
            values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("newvalue"));
            
            vals = cm.GetValues("section1", "prop1");
            Assertion.Assert(vals != null && vals.Length == 1);
            Assertion.Assert(vals[0].Equals("newvalue"));
            
            // save, unload and make sure unload is ok
            cm.SaveFile(@"..\..\test_files\testtemp.ini");
            cm.RemoveFile(@"..\..\test_files\testtemp.ini");
            Assertion.AssertNull(cm.GetValue("section1", "prop1"));

            // test if changes were saved properly
            cm.ReloadFile(@"..\..\test_files\testtemp.ini");
            
            values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("newvalue"));
            
            vals = cm.GetValues("section1", "prop1");
            Assertion.Assert(vals != null && vals.Length == 1);
            Assertion.Assert(vals[0].Equals("newvalue"));

            // Added to maintain original state prior to test
            // This prevents subsequent runnings of the test from
            // failing due to the file already being loaded.
            cm.RemoveFile(@"..\..\test_files\testtemp.ini");
        }
        
        /// <summary>
        /// Test save to xml.
        /// </summary>
        [Test]
        public void TestSaveToXml()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            String values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("value1"));
            
            Assertion.Assert(cm.SetValue("section1", "prop1", "newvalue"));
            
            values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("newvalue"));
            
            String[] vals = cm.GetValues("section1", "prop1");
            Assertion.Assert(vals != null && vals.Length == 1);
            Assertion.Assert(vals[0].Equals("newvalue"));
            
            // save, unload and make sure unload is ok
            cm.SaveFileTo(@"..\..\test_files\test.ini", @"..\..\test_files\testtemp.xml");
            cm.RemoveFile(@"..\..\test_files\test.ini");
            Assertion.AssertNull(cm.GetValue("section1", "prop1"));
            
            // test if changes were saved properly
            cf = cm.LoadFile(@"..\..\test_files\testtemp.xml");
            
            values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("newvalue"));
            
            vals = cm.GetValues("section1", "prop1");
            Assertion.Assert(vals != null && vals.Length == 1);
            Assertion.Assert(vals[0].Equals("newvalue"));
            
            // save, unload and make sure unload is ok
            cm.SaveFile(@"..\..\test_files\testtemp.xml");
            cm.RemoveFile(@"..\..\test_files\testtemp.xml");
            Assertion.AssertNull(cm.GetValue("section1", "prop1"));
            
            // test if changes were saved properly
            cf = cm.LoadFile(@"..\..\test_files\testtemp.xml");
            
            values = cm.GetValue("section1", "prop1");
            Assertion.Assert(values != null && values.Equals("newvalue"));
            
            vals = cm.GetValues("section1", "prop1");
            Assertion.Assert(vals != null && vals.Length == 1);
            Assertion.Assert(vals[0].Equals("newvalue"));

            // Added to maintain original state prior to test
            // This prevents subsequent runnings of the test from
            // failing due to the file already being loaded.
            cm.RemoveFile(@"..\..\test_files\testtemp.xml");
        }
    }
}
