// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author BAman
// @author adic
// @version 1.0

using System;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.UnitTests
{
    /// <summary>
    /// Unit tests for the Namespace class
    /// </summary>
    [TestFixture]
    public class NamespaceUnitTestCase
    {
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
			cm.Clear();
        }

        /// <summary>
        /// Tests the GetProperty method of Namespace
        /// </summary>
        [Test]
        public void TestGetProperty()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            Namespace namespaceObject = cm.GetNamespace("section2");
            Assertion.AssertNotNull(namespaceObject);
            Property prop = namespaceObject.GetProperty("prop3");
            Assertion.AssertNotNull(prop);
            Assertion.AssertEquals(3, prop.Values.Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml", "override");
            
            namespaceObject = cm.GetNamespace("override");
            Assertion.AssertNotNull(namespaceObject);
            prop = namespaceObject.GetProperty("p1");
            Assertion.AssertNotNull(prop);
            Assertion.AssertEquals(2, prop.Values.Length);

            cm.RemoveFile(@"..\..\test_files\test3.xml");
        }

        /// <summary>
        /// Tests the Properties field of Namespace
        /// </summary>
        [Test]
        public void TestProperties()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            Namespace namespaceObject = cm.GetNamespace("section2");
            Assertion.AssertNotNull(namespaceObject);
            Assertion.AssertEquals(3, namespaceObject.Properties.Length);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml", "override");
            
            namespaceObject = cm.GetNamespace("override");
            Assertion.AssertNotNull(namespaceObject);
            Assertion.AssertEquals(1, namespaceObject.Properties.Length);

            cm.RemoveFile(@"..\..\test_files\test3.xml");
        }

        /// <summary>
        /// Tests the indexer of Namespace
        /// </summary>
        [Test]
        public void TestIndexer()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            Namespace namespaceObject = cm.GetNamespace("section2");
            Assertion.AssertNotNull(namespaceObject);
            string propValue = namespaceObject["prop3"];
            Assertion.AssertEquals("value1", propValue);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml", "override");
            
            namespaceObject = cm.GetNamespace("override");
            Assertion.AssertNotNull(namespaceObject);
            propValue = namespaceObject["p1"];
            Assertion.AssertEquals("v1", propValue);

            cm.RemoveFile(@"..\..\test_files\test3.xml");
        }

        /// <summary>
        /// Tests the name field of Namespace
        /// </summary>
        [Test]
        public void TestName()
        {
            Assertion.AssertNotNull(cm);
            ConfigFile cf = cm.LoadFile(@"..\..\test_files\test.ini");
            
            Namespace namespaceObject = cm.GetNamespace("section2");
            Assertion.AssertNotNull(namespaceObject);
            Assertion.AssertEquals("section2", namespaceObject.Name);

            cm.RemoveFile(@"..\..\test_files\test.ini");

            cf = cm.LoadFile(@"..\..\test_files\test3.xml", "override");
            
            namespaceObject = cm.GetNamespace("override");
            Assertion.AssertNotNull(namespaceObject);
            Assertion.AssertEquals("override", namespaceObject.Name);

            cm.RemoveFile(@"..\..\test_files\test3.xml");
        }
    }
}
