// Copyright (c)2003, TopCoder, Inc. All rights reserved
// @author adic
// @version 1.0

using System;
using NUnit.Framework;

namespace TopCoder.Util.ConfigurationManager.StressTests
{
    /// <summary>
    /// Functional tests for the Change Properties Values use case.
    /// </summary>
    [TestFixture]
    public class BenchmarkTests
    {
        /// <summary>
        /// The prefix for all filenames.
        /// </summary>
        private const string PREFIX = @"..\..\test_files\stress\";

        /// <summary>
        /// Aproximate time to run one test.
        /// </summary>
        private const int TIME = 3000;
    	
        /// <summary>
        /// The configuration manager instance.
        /// </summary>
        private ConfigManager cm = null;
        
        /// <summary>
        /// Set up.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            cm = ConfigManager.GetInstance();
        }

        /// <summary>
        /// Tear down.
        /// </summary>
        [TearDown]
        public void TearDown()
        {
        }      
                
        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestManyNamespacesXml() 
        {        
            LoadBenchmark("stressManyNS.xml");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestManyPropertiesXml() 
        {        
            LoadBenchmark("stressManyPP.xml");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestManyValuesXml() 
        {        
            LoadBenchmark("stressManyVL.xml");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestBigXml() 
        {        
            LoadBenchmark("stressBig.xml");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestMergeXml() 
        {        
            LoadBenchmark("stressMerge.xml");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestNormalXml() 
        {        
            LoadBenchmark("stressNormal.xml");				
            Console.Out.WriteLine();
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestManyNamespacesIni() 
        {        
            LoadBenchmark("stressManyNS.ini");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestManyPropertiesIni() 
        {        
            LoadBenchmark("stressManyPP.ini");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestManyValuesIni() 
        {        
            LoadBenchmark("stressManyVL.ini");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestBigIni() 
        {        
            LoadBenchmark("stressBig.ini");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestMergeIni() 
        {        
            LoadBenchmark("stressMerge.ini");				
        }

        /// <summary>
        /// Benchmark the LoadFile method.
        /// </summary>
        [Test]
        public void TestNormalIni() 
        {        
            LoadBenchmark("stressNormal.ini");				
            Console.Out.WriteLine();
        }

        /// <summary>
        /// Benchmark the loading of a configuration file.
        /// </summary>
        /// <param name="filename">the configuration file to be loaded</param>
        public void LoadBenchmark(string filename) 
        {        
            long start = Environment.TickCount;
            long count = 0;
            int[] config = new int[3];
            while (Environment.TickCount - start < TIME) 
            {
                cm.Clear();
                cm.LoadFile(PREFIX + filename, new MyErrorCallback());				
                //cm.LoadFile(PREFIX + filename);				
                config[0] = cm.Namespaces.Length;
                config[1] = cm.Namespaces[0].Properties.Length;
                config[2] = cm.Namespaces[0].Properties[0].Values.Length;
                count++;
            }
            long stop = Environment.TickCount;
            Console.Out.WriteLine((stop - start) / count + "ms / [" + 
                config[0] + " namespaces x " + config[1] + " properties x " + 
                config[2] + " values = " + (config[0] * config[1] * config[2]) + 
                "] " + filename + " (" + count + " runs)");
        }                
    }

    [Serializable]
    internal class MyErrorCallback: ErrorCallback
    {
        public ErrorAction NamespaceCollision(Namespace oldNamespace, Namespace newNamespace)
        {
            return ErrorAction.Merge;
        }

        public ErrorAction PropertyCollision(Namespace ns, Property oldProperty, Property newProperty)
        {            
            return ErrorAction.Merge;
        }

        public bool CriticalError(Exception exception)
        {
            return false;
        }
    }
}
