// Copyright (c)2005, TopCoder, Inc. All rights reserved
// @author TCSDEVELOPER
// @version 2.0

using System;

namespace TopCoder.Util.ConfigurationManager.UnitTests
{
    /// <summary>
    /// Sample base class (basic type) to test ConfigManager.CreateInstance()
    /// </summary>
    public class IServer
    {
        public IServer()
        {
        }
    }
    /// <summary>
    /// Default implementation of IServer. Try to create an instance of SmtpServer
    /// using ConfigManager.CreateInstance() by loading the testclass.xml file
    /// which contains information on the class name and assembly.
    /// </summary>
    public class SmtpServer : IServer
    {
        /// <summary>
        /// server name.
        /// </summary>
        private string name = "smtp.myserver.com";

        /// <summary>
        /// port on which this smtp server runs.
        /// </summary>
        private short port = 25;

        /// <summary>
        /// Default constructor.
        /// </summary>
        public SmtpServer()
        {
        }

        /// <summary>
        /// Constructor with server name.
        /// </summary>
        /// <param name="server"></param>
        public SmtpServer (string server)
        {
            name = server;
        }

        /// <summary>
        /// Constructor with both name and port number.
        /// </summary>
        /// <param name="server"></param>
        /// <param name="port"></param>
        public SmtpServer (string server, short port)
        {
            name = server;
            this.port = port;
        }

        /// <summary>
        /// Prints the server name and port.
        /// </summary>
        public void PrintNameAndPort()
        {
            System.Console.WriteLine("Server details {0}:{1}", name, port);
        }

        /// <summary>
        /// Gets the server name.
        /// </summary>
        /// <returns>The SMTP server name.</returns>
        public string Name()
        {
            return name;
        }

        /// <summary>
        /// Get the port number.
        /// </summary>
        /// <returns>The port on which this server will run.</returns>
        public short Port()
        {
            return port;
        }
    }
}
